@@ -59,38 +59,27 @@ typedef enum
 } EphyPrefsProcessModel;
 
 #define EPHY_PREFS_UI_SCHEMA                     "org.gnome.Epiphany.ui"
-#define EPHY_PREFS_UI_ALWAYS_SHOW_TABS_BAR       "always-show-tabs-bar"
-#define EPHY_PREFS_UI_DOWNLOADS_HIDDEN           "downloads-hidden"
 #define EPHY_PREFS_UI_EXPAND_TABS_BAR            "expand-tabs-bar"
 #define EPHY_PREFS_UI_TABS_BAR_POSITION          "tabs-bar-position"
 #define EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY "tabs-bar-visibility-policy"
 
 #define EPHY_PREFS_STATE_SCHEMA                 "org.gnome.Epiphany.state"
-#define EPHY_PREFS_STATE_SAVE_DIR               "save-dir"
-#define EPHY_PREFS_STATE_SAVE_IMAGE_DIR         "save-image-dir"
-#define EPHY_PREFS_STATE_OPEN_DIR               "open-dir"
 #define EPHY_PREFS_STATE_DOWNLOAD_DIR           "download-dir"
-#define EPHY_PREFS_STATE_UPLOAD_DIR             "upload-dir"
 #define EPHY_PREFS_STATE_RECENT_ENCODINGS       "recent-encodings"
-#define EPHY_PREFS_STATE_BOOKMARKS_VIEW_TITLE   "bookmarks-view-title"
-#define EPHY_PREFS_STATE_BOOKMARKS_VIEW_ADDRESS "bookmarks-view-address"
 
 #define EPHY_PREFS_WEB_SCHEMA                "org.gnome.Epiphany.web"
 #define EPHY_PREFS_WEB_FONT_MIN_SIZE         "min-font-size"
 #define EPHY_PREFS_WEB_LANGUAGE              "language"
-#define EPHY_PREFS_WEB_USE_OWN_FONTS         "use-own-fonts"
 #define EPHY_PREFS_WEB_USE_GNOME_FONTS       "use-gnome-fonts"
 #define EPHY_PREFS_WEB_SANS_SERIF_FONT       "sans-serif-font"
 #define EPHY_PREFS_WEB_SERIF_FONT            "serif-font"
 #define EPHY_PREFS_WEB_MONOSPACE_FONT        "monospace-font"
-#define EPHY_PREFS_WEB_USE_OWN_COLORS        "use-own-colors"
 #define EPHY_PREFS_WEB_ENABLE_USER_CSS       "enable-user-css"
 #define EPHY_PREFS_WEB_ENABLE_POPUPS         "enable-popups"
 #define EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING "enable-spell-checking"
 #define EPHY_PREFS_WEB_ENABLE_WEBGL          "enable-webgl"
 #define EPHY_PREFS_WEB_ENABLE_WEBAUDIO       "enable-webaudio"
 #define EPHY_PREFS_WEB_COOKIES_POLICY        "cookies-policy"
-#define EPHY_PREFS_WEB_IMAGE_ANIMATION_MODE  "image-animation-mode"
 #define EPHY_PREFS_WEB_DEFAULT_ENCODING      "default-encoding"
 #define EPHY_PREFS_WEB_DO_NOT_TRACK          "do-not-track"
 #define EPHY_PREFS_WEB_ENABLE_ADBLOCK        "enable-adblock"
@@ -102,7 +91,6 @@ typedef enum
 #define EPHY_PREFS_WARN_ON_CLOSE_UNSUBMITTED_DATA "warn-on-close-unsubmitted-data"
 #define EPHY_PREFS_REMEMBER_PASSWORDS             "remember-passwords"
 #define EPHY_PREFS_KEYWORD_SEARCH_URL             "keyword-search-url"
-#define EPHY_PREFS_MANAGED_NETWORK                "managed-network"
 #define EPHY_PREFS_ENABLE_SMOOTH_SCROLLING        "enable-smooth-scrolling"
 #define EPHY_PREFS_ENABLE_CARET_BROWSING          "enable-caret-browsing"
 #define EPHY_PREFS_INTERNAL_VIEW_SOURCE           "internal-view-source"
