@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2013 Bastien Nocera <hadess@hadess.net>
- *  Copyright © 2016 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of Epiphany.
+ *
+ *  Epiphany is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -248,7 +249,7 @@ ephy_remove_tracking_from_uri (const char *uri_string)
   return ret;
 }
 
-char *
+static char *
 ephy_uri_decode (const char *uri_string)
 {
   char *decoded_uri;
@@ -262,6 +263,41 @@ ephy_uri_decode (const char *uri_string)
   return decoded_uri ? decoded_uri : g_strdup (uri_string);
 }
 
+char *
+ephy_uri_sanitize (const char *uri_string)
+{
+  SoupURI *uri;
+  char *sanitized_uri;
+
+  /* Trick: the parameter does not actually have to be a URI. We allow calling
+   * this function with any address, like about:blank. Just return in that case.
+   */
+  uri = soup_uri_new (uri_string);
+  if (!uri)
+    return g_strdup (uri_string);
+
+  /* Use soup_uri_to_string to remove the password component of the URI. */
+  sanitized_uri = soup_uri_to_string (uri, FALSE);
+  soup_uri_free (uri);
+
+  return sanitized_uri;
+}
+
+char *
+ephy_uri_decode_and_sanitize (const char *uri_string)
+{
+
+  char *sanitized_uri;
+  char *result;
+
+  sanitized_uri = ephy_uri_sanitize (uri_string);
+  result = ephy_uri_decode (sanitized_uri);
+
+  g_free (sanitized_uri);
+
+  return result;
+}
+
 char *
 ephy_uri_normalize (const char *uri_string)
 {
@@ -281,50 +317,4 @@ ephy_uri_normalize (const char *uri_string)
   return encoded_uri;
 }
 
-char *
-ephy_uri_to_security_origin (const char *uri_string)
-{
-  SoupURI *uri;
-  char *result;
-
-  /* Convert to URI containing only protocol, host, and port. */
-  uri = soup_uri_new (uri_string);
-  if (uri == NULL)
-    return NULL;
-
-  if (uri->scheme == SOUP_URI_SCHEME_FILE ||
-      uri->scheme == SOUP_URI_SCHEME_DATA)
-    return NULL;
-
-  if (soup_uri_uses_default_port (uri))
-    result = g_strdup_printf ("%s://%s", uri->scheme, uri->host);
-  else
-    result = g_strdup_printf ("%s://%s:%u", uri->scheme, uri->host, uri->port);
-  soup_uri_free (uri);
-
-  return result;
-}
-
-char *
-ephy_uri_to_https_security_origin (const char *uri_string)
-{
-  SoupURI *uri;
-  char *result;
-
-  /* Convert to URI containing only protocol, host, and port. */
-  uri = soup_uri_new (uri_string);
-  if (uri == NULL)
-    return NULL;
-
-  if (uri->scheme == SOUP_URI_SCHEME_FILE ||
-      uri->scheme == SOUP_URI_SCHEME_DATA)
-    return NULL;
-
-  if (soup_uri_uses_default_port (uri))
-    result = g_strdup_printf ("https://%s", uri->host);
-  else
-    result = g_strdup_printf ("https://%s:%u", uri->host, uri->port);
-  soup_uri_free (uri);
-
-  return result;
-}
+/* vim: set sw=2 ts=2 sts=2 et: */
